pub struct ActiveTask {
pub id: Uuid,
pub target: UnixNanos,
pub timeout: TimeoutPolicy,
}Expand description
A task that is not finished and not pending anymore.
It is used to keep track of timeouts for tasks that are already running when the scheduler starts.
Fields
id: UuidThe task’s ID.
target: UnixNanosThe task’s target timestamp.
timeout: TimeoutPolicyThe task’s timeout policy.